#!/usr/bin/env python
from . import cli
from dotenvy import load_env, read_file
from os import path


__version__ = '0.1.0'


def main():
    if path.exists('.env'):
        load_env(read_file('.env'))

    cli.main(obj={})


if __name__ == '__main__':
    main()



import click
import requests
try:
    import simplejson as json
except ImportError:
    import json
from sh import git


DEFAULT_GITHUB_URL = 'https://api.github.com'
DEFAULT_CONTEXT = 'default'
STATES = ['error', 'failure', 'pending', 'success']


def lstrip(text, prefix):
    return text[len(prefix):] if text.startswith(prefix) else text


def rstrip(text, suffix):
    return text[:len(text) - len(suffix)] if text.endswith(suffix) else text


def get_repo():
    url = str(git('config', 'remote.origin.url')).strip()
    url = lstrip(url, 'git@github.com:')
    url = lstrip(url, 'https://github.com/')
    url = rstrip(url, '.git')
    return url


def get_sha():
    return str(git('rev-parse', 'HEAD')).strip()


@click.group()
@click.option('base_url', '--base-url', type=str, envvar='GITHUB_URL',
              default=DEFAULT_GITHUB_URL, show_default=True,
              help='GitHub API URL [env: GITHUB_URL]')
@click.option('username', '-u', type=str, envvar='GITHUB_USERNAME',
              help='GitHub API username [env: GITHUB_USERNAME]')
@click.option('password', '-p', type=str, envvar='GITHUB_PASSWORD',
              help='GitHub API password/token [env: GITHUB_PASSWORD]')
@click.option('repo', '--repo', envvar='GITHUB_REPO')
@click.option('sha', '--sha', envvar='GITHUB_SHA')
@click.pass_context
def main(ctx, base_url, username, password, repo, sha):
    ctx.obj['base_url'] = base_url
    ctx.obj['username'] = username
    ctx.obj['password'] = password
    ctx.obj['repo'] = repo
    ctx.obj['sha'] = sha


@main.command()
@click.option('--context', default=DEFAULT_CONTEXT, show_default=True)
@click.option('--description')
@click.option('--target-url')
@click.argument('state', type=click.Choice(STATES))
@click.pass_context
def set(ctx, state, context, description, target_url):
    base_url = ctx.obj.get('base_url')
    username = ctx.obj.get('username')
    password = ctx.obj.get('password')
    repo = ctx.obj.get('repo') or get_repo()
    sha = ctx.obj.get('sha') or get_sha()
    status_url = '%s/repos/%s/statuses/%s' % (base_url, repo, sha)

    payload = {
        'context': context,
        'state': state,
        'description': description,
        'target_url': target_url,
    }

    print(locals())

    r = requests.post(status_url, json=payload, auth=(username, password))
    click.echo(json.dumps(r.json(), indent=2))


@main.command()
@click.option('--context', default=DEFAULT_CONTEXT, show_default=True)
@click.option('json_output', '--json/--no-json', is_flag=True, default=True)
@click.pass_context
def get(ctx, context, json_output):
    base_url = ctx.obj.get('base_url')
    username = ctx.obj.get('username')
    password = ctx.obj.get('password')
    repo = ctx.obj.get('repo') or get_repo()
    sha = ctx.obj.get('sha') or get_sha()
    status_url = '%s/repos/%s/statuses/%s' % (base_url, repo, sha)

    r = requests.get(status_url, auth=(username, password))
    if json_output:
        click.echo(json.dumps(r.json(), indent=2))
    else:
        for s in r.json():
            line = '[%s] %s - %s' % (s['context'], s['state'], s['description'])
            click.echo(line)

    if r.status_code != 200:
        exit(1)



#!/usr/bin/env python
from setuptools import setup, find_packages


REPO_NAME = 'chickenzord/ghstatus'
VERSION = '0.1.0'
ARCHIVE_URL = 'https://github.com/%s/archive/v%s.tar.gz' % (REPO_NAME, VERSION)

setup(
    # packaging
    packages=find_packages('src'),
    package_dir={'': 'src'},
    package_data={},
    install_requires=[
        'click',
        'requests',
        'sh',
    ],
    setup_requires=[
        'flake8',
    ],
    tests_require=[
    ],
    entry_points={
        "console_scripts": ['ghstatus = ghstatus:main']
    },
    zip_safe=False,

    # metadata
    name='ghstatus',
    version=VERSION,
    author='Akhyar Amarullah',
    author_email='akhyrul@gmail.com',
    description='GitHub commit status updater',
    long_description=open('README.rst').read(),
    download_url=ARCHIVE_URL,
    license='MIT',
    keywords=['github', 'continuous-integration'],
    url='https://github.com/%s' % (REPO_NAME),
    classifiers=[
        'Development Status :: 4 - Beta',
        'License :: OSI Approved :: MIT License',
        'Intended Audience :: Developers',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: Software Development :: Libraries',
        'Topic :: Utilities',
    ],
)
